==> seedsui-react-5.5.91.tgz: package/lib/Picker/Deprecated/Picker.js <==
var _excluded = ["portal", "list", "show", "value", "selected", "maskAttribute", "submitAttribute", "cancelAttribute", "slotAttribute"],
    _excluded2 = ["caption", "onClick"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect, useContext } from 'react';
import { createPortal } from 'react-dom';
import Instance from "./instance.js";
import Context from "../../Context/instance.js";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Picker = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var portal = _ref.portal,
      _ref$list = _ref.list,
      list = _ref$list === void 0 ? [] : _ref$list,
      _ref$show = _ref.show,
      show = _ref$show === void 0 ? false : _ref$show,
      value = _ref.value,
      selected = _ref.selected,
      _ref$maskAttribute = _ref.maskAttribute,
      maskAttribute = _ref$maskAttribute === void 0 ? {} : _ref$maskAttribute,
      _ref$submitAttribute = _ref.submitAttribute,
      submitAttribute = _ref$submitAttribute === void 0 ? {} : _ref$submitAttribute,
      _ref$cancelAttribute = _ref.cancelAttribute,
      cancelAttribute = _ref$cancelAttribute === void 0 ? {} : _ref$cancelAttribute,
      _ref$slotAttribute = _ref.slotAttribute,
      slotAttribute = _ref$slotAttribute === void 0 ? {} : _ref$slotAttribute,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  var instance = useRef(null);
  useEffect(function () {
    initInstance();
  }, []); // eslint-disable-line

  useEffect(function () {
    if (instance.current) {
      if (show && list.length) {
        setDefault();
        instance.current.show();
      } else {
        instance.current.hide();
      }
    } else if (list && list.length > 0) {
      initInstance();
    }
  }, [show]); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.params.onClickSubmit = clickSubmit;
    instance.current.params.onClickCancel = clickCancel;
    instance.current.params.onClickMask = clickMask;
  }

  function clickSubmit(e) {
    var value = e.activeOptions[0].name;
    var options = e.activeOptions;
    if (submitAttribute.onClick) submitAttribute.onClick(e, value, options);
  }

  function clickCancel(e) {
    if (cancelAttribute.onClick) cancelAttribute.onClick(e);
  }

  function clickMask(e) {
    if (maskAttribute.onClick) maskAttribute.onClick(e);
  }

  function setDefault() {
    var defaultOpt = getDefaultOption();
    if (!defaultOpt) return;
    instance.current.clearSlots();
    instance.current.addSlot(list, defaultOpt.id || '', slotAttribute.className || 'text-center'); // 添加列,参数:数据,默认id,样式(lock样式为锁定列)
  }

  function getDefaultOption() {
    if (selected && selected.length) {
      return selected[0];
    }

    if (value) {
      var _iterator = _createForOfIteratorHelper(list),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var item = _step.value;
          if (item.name === value) return item;
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }

    if (list && list.length) {
      return list[0];
    }

    return null;
  }

  function initInstance() {
    if (!list || !list.length || instance.current) {
      console.log('SeedsUI Picker: 参数list为空');
      return;
    } // render数据


    instance.current = new Instance({
      mask: rootRef.current,
      onClickMask: clickMask,
      onClickCancel: clickCancel,
      onClickSubmit: clickSubmit,
      onHid: function onHid(e) {}
    }); // 默认项

    var defaultOpt = getDefaultOption();
    var id = '';
    if (defaultOpt && defaultOpt.id) id = defaultOpt.id;
    instance.current.addSlot(list, id, slotAttribute.className || 'text-center');

    if (show && instance.current) {
      instance.current.show();
    }

    rootRef.current.instance = instance;
  } // 过滤已经回调的属性


  function filterProps(props) {
    if (!props) return {};

    var caption = props.caption,
        onClick = props.onClick,
        otherProps = _objectWithoutProperties(props, _excluded2);

    return _objectSpread({}, otherProps);
  } // context


  var context = useContext(Context) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  }; // 剔除掉onClick事件, 因为在instance时已经回调了


  var otherMaskAttribute = filterProps(maskAttribute);
  var otherSubmitAttribute = filterProps(submitAttribute);
  var otherCancelAttribute = filterProps(cancelAttribute);
  return /*#__PURE__*/createPortal( /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
    ref: rootRef
  }, otherMaskAttribute), {}, {
    className: "mask picker-mask".concat(otherMaskAttribute.className ? ' ' + otherMaskAttribute.className : ''),
    children: /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({}, others), {}, {
      className: "picker".concat(others.className ? ' ' + others.className : ''),
      children: [/*#__PURE__*/_jsxs("div", {
        className: "picker-header",
        children: [/*#__PURE__*/_jsx("a", _objectSpread(_objectSpread({}, otherCancelAttribute), {}, {
          className: "picker-cancel".concat(cancelAttribute.className ? ' ' + cancelAttribute.className : ''),
          children: cancelAttribute.caption || locale('取消', 'cancel')
        })), /*#__PURE__*/_jsx("div", {
          className: "picker-header-title"
        }), /*#__PURE__*/_jsx("a", _objectSpread(_objectSpread({}, otherSubmitAttribute), {}, {
          className: "picker-submit".concat(submitAttribute.className ? ' ' + submitAttribute.className : ''),
          children: submitAttribute.caption || locale('完成', 'finish')
        }))]
      }), /*#__PURE__*/_jsxs("div", {
        className: "picker-wrapper",
        children: [/*#__PURE__*/_jsx("div", {
          className: "picker-layer",
          children: /*#__PURE__*/_jsx("div", {
            className: "picker-layer-frame"
          })
        }), /*#__PURE__*/_jsx("div", {
          className: "picker-slotbox"
        })]
      })]
    }))
  })), portal || context.portal || document.getElementById('root') || document.body);
});
export default /*#__PURE__*/React.memo(Picker, function (prevProps, nextProps) {
  if (nextProps.show === prevProps.show) return true;
  return false;
});

==> seedsui-react-5.5.92.tgz: package/lib/Picker/Deprecated/Picker.js <==
var _excluded = ["portal", "list", "show", "value", "selected", "maskAttribute", "submitAttribute", "cancelAttribute", "slotAttribute"],
    _excluded2 = ["caption", "onClick"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect, useContext } from 'react';
import { createPortal } from 'react-dom';
import Instance from "./instance.js";
import Context from "../../Context/instance.js";
var Picker = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var portal = _ref.portal,
      _ref$list = _ref.list,
      list = _ref$list === void 0 ? [] : _ref$list,
      _ref$show = _ref.show,
      show = _ref$show === void 0 ? false : _ref$show,
      value = _ref.value,
      selected = _ref.selected,
      _ref$maskAttribute = _ref.maskAttribute,
      maskAttribute = _ref$maskAttribute === void 0 ? {} : _ref$maskAttribute,
      _ref$submitAttribute = _ref.submitAttribute,
      submitAttribute = _ref$submitAttribute === void 0 ? {} : _ref$submitAttribute,
      _ref$cancelAttribute = _ref.cancelAttribute,
      cancelAttribute = _ref$cancelAttribute === void 0 ? {} : _ref$cancelAttribute,
      _ref$slotAttribute = _ref.slotAttribute,
      slotAttribute = _ref$slotAttribute === void 0 ? {} : _ref$slotAttribute,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  var instance = useRef(null);
  useEffect(function () {
    initInstance();
  }, []); // eslint-disable-line

  useEffect(function () {
    if (instance.current) {
      if (show && list.length) {
        setDefault();
        instance.current.show();
      } else {
        instance.current.hide();
      }
    } else if (list && list.length > 0) {
      initInstance();
    }
  }, [show]); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.params.onClickSubmit = clickSubmit;
    instance.current.params.onClickCancel = clickCancel;
    instance.current.params.onClickMask = clickMask;
  }

  function clickSubmit(e) {
    var value = e.activeOptions[0].name;
    var options = e.activeOptions;
    if (submitAttribute.onClick) submitAttribute.onClick(e, value, options);
  }

  function clickCancel(e) {
    if (cancelAttribute.onClick) cancelAttribute.onClick(e);
  }

  function clickMask(e) {
    if (maskAttribute.onClick) maskAttribute.onClick(e);
  }

  function setDefault() {
    var defaultOpt = getDefaultOption();
    if (!defaultOpt) return;
    instance.current.clearSlots();
    instance.current.addSlot(list, defaultOpt.id || '', slotAttribute.className || 'text-center'); // 添加列,参数:数据,默认id,样式(lock样式为锁定列)
  }

  function getDefaultOption() {
    if (selected && selected.length) {
      return selected[0];
    }

    if (value) {
      var _iterator = _createForOfIteratorHelper(list),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var item = _step.value;
          if (item.name === value) return item;
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }

    if (list && list.length) {
      return list[0];
    }

    return null;
  }

  function initInstance() {
    if (!list || !list.length || instance.current) {
      console.log('SeedsUI Picker: 参数list为空');
      return;
    } // render数据


    instance.current = new Instance({
      mask: rootRef.current,
      onClickMask: clickMask,
      onClickCancel: clickCancel,
      onClickSubmit: clickSubmit,
      onHid: function onHid(e) {}
    }); // 默认项

    var defaultOpt = getDefaultOption();
    var id = '';
    if (defaultOpt && defaultOpt.id) id = defaultOpt.id;
    instance.current.addSlot(list, id, slotAttribute.className || 'text-center');

    if (show && instance.current) {
      instance.current.show();
    }

    rootRef.current.instance = instance;
  } // 过滤已经回调的属性


  function filterProps(props) {
    if (!props) return {};

    var caption = props.caption,
        onClick = props.onClick,
        otherProps = _objectWithoutProperties(props, _excluded2);

    return _objectSpread({}, otherProps);
  } // context


  var context = useContext(Context) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  }; // 剔除掉onClick事件, 因为在instance时已经回调了


  var otherMaskAttribute = filterProps(maskAttribute);
  var otherSubmitAttribute = filterProps(submitAttribute);
  var otherCancelAttribute = filterProps(cancelAttribute);
  return /*#__PURE__*/createPortal( /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef
  }, otherMaskAttribute, {
    className: "mask picker-mask".concat(otherMaskAttribute.className ? ' ' + otherMaskAttribute.className : '')
  }), /*#__PURE__*/React.createElement("div", _extends({}, others, {
    className: "picker".concat(others.className ? ' ' + others.className : '')
  }), /*#__PURE__*/React.createElement("div", {
    className: "picker-header"
  }, /*#__PURE__*/React.createElement("a", _extends({}, otherCancelAttribute, {
    className: "picker-cancel".concat(cancelAttribute.className ? ' ' + cancelAttribute.className : '')
  }), cancelAttribute.caption || locale('取消', 'cancel')), /*#__PURE__*/React.createElement("div", {
    className: "picker-header-title"
  }), /*#__PURE__*/React.createElement("a", _extends({}, otherSubmitAttribute, {
    className: "picker-submit".concat(submitAttribute.className ? ' ' + submitAttribute.className : '')
  }), submitAttribute.caption || locale('完成', 'finish'))), /*#__PURE__*/React.createElement("div", {
    className: "picker-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    className: "picker-layer"
  }, /*#__PURE__*/React.createElement("div", {
    className: "picker-layer-frame"
  })), /*#__PURE__*/React.createElement("div", {
    className: "picker-slotbox"
  })))), portal || context.portal || document.getElementById('root') || document.body);
});
export default /*#__PURE__*/React.memo(Picker, function (prevProps, nextProps) {
  if (nextProps.show === prevProps.show) return true;
  return false;
});
